# moniplot
Moniplot is a Python data visualization library based on
[matplotlib](https://matplotlib.org) and [xarray](https://xarray.pydata.org).
It provides a high-level interface for drawing attractive and informative
graphics of onground calibration data analysis or inflight instrument
monitoring.

Note that this project has just started and all software is still under
developement. Therefore, its API is still not stable.

The class MONplot is a rewrite of pyS5p::S5Pplot. The latter was developed for
data of the Tropomi SWIR instrument on Sentinel 5 precursor. MONplot should
not be limited to a particular instrument (with a 2D detector).
